%define fullgit 2747c961015ba00ec9a1cad8a8a95b4a34db9ee0
%define git 0

%define rel 3

%if %{git}
%define release %mkrel -c %{git} %{rel}
%else
%define release %mkrel %{rel}
%endif

%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

# (cg) Lennart has introduced a circular dependancy in the libraries
# libpulse requires libpulsecommon but libpulsecommon requires libpulse.
# This breaks no-undefined.
# Further issues in some test apps (maybe more) require that disabling
# as-needed is also required.
%define _disable_ld_no_undefined 1

%global __requires_exclude devel\\(libpulsecommon

# Majors
%define major 0
%define glib2major 0
%define apiver 17.0

# Library names
%define libname       %mklibname %{name} %{major}
%define libname_devel %mklibname %{name} -d

%define glib2libname  %mklibname pulseglib2 %{glib2major}

# API libs (not real shared libs - mostly private but needed by other libs and server)
%define corelibname   %mklibname pulsecore %{apiver}
%define commonlibname %mklibname pulsecommon %{apiver}


Summary:        Sound server for Linux
Name:           pulseaudio
Version:        17.0
Release:        %{release}
# Airtunes links to OpenSSL which is BSD-like and should be reflected here
License:        LGPL and BSD-like
Group:          Sound/Mixers
Url:            https://pulseaudio.org/
%if %{git}
Source0:        %{name}-%{version}-%{fullgit}.tar.xz
%else
Source0:        https://freedesktop.org/software/pulseaudio/releases/%{name}-%{version}.tar.xz
%endif
Source1:        %{name}.sysconfig
Source2:        %{name}.xinit
Source4:        %{name}.svg

# (cg) Using git to manage patches
# To recreate the structure
# git clone git://git.0pointer.de/pulseaudio
# git checkout v1.0
# git checkout -b mdv-1.x-cherry-picks
# git am 00*.patch
# git checkout -b mga-1.x-patches
# git am 05*.patch

# To apply new custom patches
# git checkout mga-1.x-patches
# (do stuff)

# To apply new cherry-picks
# git checkout mdv-1.x-cherry-picks
# git cherry-pick <blah>
# git checkout mga-1.x-patches
# git rebase mdv-1.x-cherry-picks

# Stable Branch Patches
# git format-patch --start-number 100 v1.0..stable-1.x

## upstream patches
#

# Mageia Patches
# git format-patch --start-number 500 table-1.x..mga-1.x-patches
Patch500:       0500-Some-customisations-to-esdcompat-in-order-to-adhere-.patch
Patch501:       0501-launch-Customise-systemd-socket-for-Mageia-sound-pro.patch

# from ubuntu (https://git.launchpad.net/~ubuntu-audio-dev/pulseaudio)
Patch0600:      0001-volume-config-changes.patch
Patch0601:      0030-load-module-switch-on-connect.patch

BuildRequires:  meson
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(soxr)
BuildRequires:  pkgconfig(speexdsp) >= 1.2
BuildRequires:  libwrap-devel
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(libudev)
#gw libtool dep:
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  doxygen
BuildRequires:  automake
BuildRequires:  libltdl-devel
BuildRequires:  pkgconfig(atomic_ops)
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(liblircclient0)
%if !%bootstrap
BuildRequires:  pkgconfig(bluez)
%endif
BuildRequires:  pkgconfig(tdb)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(speex)
# (cg) Needed for airtunes
BuildRequires:  pkgconfig(libssl) >= 1.0
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(libasyncns)
BuildRequires:  intltool
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(orc-0.4)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(webrtc-audio-processing-1)
BuildRequires:  pkgconfig(sbc)
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.16.0
BuildRequires:  pkgconfig(gstreamer-app-1.0) >= 1.16.0
BuildRequires:  pkgconfig(gstreamer-rtp-1.0) >= 1.16.0

Provides:       polypaudio
Requires:       rtkit
Requires(post): ccp

# Virtual Provides to support swapping between PipeWire-PA and PA
Provides:       pulseaudio-daemon
Conflicts:      pulseaudio-daemon

%description
PulseAudio is a sound server for Linux and other Unix like operating
systems.

PulseAudio makes possible to:
     * transfer audio to a different machine
     * change the sample format or channel count and mixing several
       sounds into one
     * combine multiple sound cards to one (with sample rate adjustment)
     * simple command line interface for reconfiguring the daemon while
       running

PulseAudio provides:
     * better low latency behaviour
     * support for more than one sink/source
     * an extensible plugin architecture (by loading dynamic loadable
       modules with dlopen())
     * a completely asynchronous C API
     * flexible, implicit sample type conversion and resampling
     * "zero-copy" architecture
     * module autoloading
     * very accurate latency measurement for playback and recording.
     * client side latency interpolation
     * C library to enable embedding into other software

%post
ccp -i -d --set NoOrphans --oldfile %{_sysconfdir}/pulse/daemon.conf --newfile %{_sysconfdir}/pulse/daemon.conf.rpmnew
# (cg) For upgrade between 1.x -> 2.x
if grep -q module-cork-music-on-phone %{_sysconfdir}/pulse/default.pa; then
  sed -i 's/module-cork-music-on-phone/module-role-cork/' %{_sysconfdir}/pulse/default.pa
fi


%package -n %{libname}
Summary:        Libraries for PulseAudio clients
Group:          System/Libraries
License:        LGPLv2+
Requires:       %{name}-client-config
Recommends:     %{mklibname alsa-plugins}-pulseaudio
%ifarch x86_64
# (cg) Suggest the 32 bit library on 64 bits to ensure compatibility
#      with (typically closed source) 32 bit apps.
Recommends:     lib%{name}%{major}
%endif

%description -n %{libname}
This package contains the runtime libraries for any application that wishes
to interface with a PulseAudio sound server.

%package -n %{corelibname}
Summary:        Core Library for PulseAudio
Group:          System/Libraries

%description -n %{corelibname}
This package contains a library needed by the PulseAudio sound server and modules.

%package -n %{commonlibname}
Summary:        Common Library for PulseAudio
Group:          System/Libraries

%description -n %{commonlibname}
This package contains a library needed by the PulseAudio sound server, modules and
clients.


%define alt_name     soundprofile
%define alt_priority 20

%package client-config
Summary:        Client configuration for PulseAudio clients
Group:          System/Libraries
# (eatdirt) Otherwise may trigger bug 2966
%if %bootstrap
Recommends:       alsa-plugins-pulse-config
%else
Recommends:       alsa-plugins-pulse-config
%endif
Requires(post): ccp
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description client-config
This package contains the client configuration files for any application that wishes
to interface with a PulseAudio sound server.


%post client-config
%{_sbindir}/update-alternatives \
  --install %{_sysconfdir}/sound/profiles/current %{alt_name} %{_sysconfdir}/sound/profiles/pulse %{alt_priority}
ccp -i -d --set NoOrphans --oldfile %{_sysconfdir}/pulse/client.conf --newfile %{_sysconfdir}/pulse/client.conf.rpmnew

%postun client-config
if [ ! -f %{_sysconfdir}/sound/profiles/pulse/profile.conf ]; then
  /usr/sbin/update-alternatives --remove %{alt_name} %{_sysconfdir}/sound/profiles/pulse
fi

%package -n %{glib2libname}
Summary:        GLIB 2.x bindings for PulseAudio clients
Group:          System/Libraries

%description -n %{glib2libname}
This package contains bindings to integrate the PulseAudio client library with
a GLIB 2.x based application.


%package -n %{libname_devel}
Summary:        Headers and libraries for PulseAudio client development
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       %{glib2libname} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       pulseaudio-libs-devel = %{version}-%{release}
Provides:       pulseaudio-libs-devel%{?_isa} = %{version}-%{release}

%description -n %{libname_devel}
Headers and libraries for developing applications that can communicate with
a PulseAudio sound server.


%package module-lirc
Summary:        LIRC support for the PulseAudio sound server
Group:          Sound/Mixers
Requires:       %{name} = %{version}-%{release}

%description module-lirc
LIRC volume control module for the PulseAudio sound server.

%if !%bootstrap
%package module-bluetooth
Summary:        Bluetooth support for the PulseAudio sound server
Group:          Sound/Mixers
Requires:       %{name} = %{version}-%{release}

%description module-bluetooth
Bluetooth modules for the PulseAudio sound server to provide support
for headsets and proximity detection.
%endif

%package module-x11
Summary:        X11 support for the PulseAudio sound server
Group:          Sound/Mixers
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-utils = %{version}-%{release}

%description module-x11
X11 bell and security modules for the PulseAudio sound server.

%package module-zeroconf
Summary:        Zeroconf support for the PulseAudio sound server
Group:          Sound/Mixers
Requires:       %{name} = %{version}-%{release}

%description module-zeroconf
Zeroconf publishing module for the PulseAudio sound server.

%package module-jack
Summary:        JACK support for the PulseAudio sound server
Group:          Sound/Mixers
Requires:       %{name} = %{version}-%{release}

%description module-jack
JACK sink and source modules for the PulseAudio sound server.

%package module-gsettings
Summary:        Gsettings support for the PulseAudio sound server
Requires:       %{name}%{?_isa} = %{version}-%{release}
Obsoletes:      %{name}-module-gconf < %{version}-%{release}

%description module-gsettings
GSettings configuration backend for the PulseAudio sound server.

%package module-equalizer
Summary:        Equalizer support for the PulseAudio sound server
Group:          Sound/Mixers
Requires:       %{name} = %{version}-%{release}
Requires:       python3-qt5-core
Requires:       python3-qt5-gui
Requires:       python3-qt5-widgets
Requires:       python3-dbus

%description module-equalizer
Equalizer support and GUI for the PulseAudio sound server.

%package utils
Summary:        PulseAudio sound server utilities
Group:          Sound/Utilities

%description utils
This package contains command line utilities for the PulseAudio sound server.


%prep
%if %{git}
%setup -q -n %{name}-%{version}-%{fullgit}
%else
%setup -q
%endif

%autopatch -p1

# python shebangs
%py3_shebang_fix ./src/utils/qpaeq

# update doxygen.conf
doxygen -u doxygen/doxygen.conf.in

%build
%meson \
  -D system_user=pulse \
  -D system_group=pulse \
  -D access_group=pulse-access \
  -D oss-output=disabled \
  -D jack=enabled \
  -D lirc=enabled \
  -D tcpwrap=disabled \
  -D bluez5=enabled \
  -D gstreamer=enabled \
  -D bluez5-gstreamer=enabled \
  -D gsettings=enabled \
  -D elogind=disabled \
  -D valgrind=disabled \
  -D gtk=disabled \
  -D soxr=enabled \
  -D webrtc-aec=enabled \
  -D systemd=enabled \
  -D udevrulesdir=%{_udevrulesdir} \
  -D tests=false

%meson_build

%meson_build doxygen

%install
export QA_RPATHS=0x0001
%meson_install

install -D -m 0644 %{_sourcedir}/%{name}.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -D -m 0755 %{_sourcedir}/%{name}.xinit %{buildroot}%{_sysconfdir}/X11/xinit.d/50%{name}

install -D -m 0644 %{_sourcedir}/%{name}.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/devices
ln -s ../apps/%{name}.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/devices/audio-backend-pulseaudio.svg
for size in 16 22 32 48 64 128; do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/{apps,devices}
  convert -geometry ${size}x${size} %{_sourcedir}/%{name}.svg %{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps/%{name}.png
  ln -s ../apps/%{name}.png %{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/devices/audio-backend-pulseaudio.png
done

# Remove static and metalink libraries
find %{buildroot} \( -name *.a -o -name *.la \) -exec rm {} \;

# (cg) For sound profile support
mkdir -p %{buildroot}%{_sysconfdir}/sound/profiles/pulse
echo "SOUNDPROFILE=pulse" >%{buildroot}%{_sysconfdir}/sound/profiles/pulse/profile.conf
# (cg) Use this file as a trigger for enabling the pulseaudio.socket systemd user unit
touch %{buildroot}%{_sysconfdir}/sound/profiles/pulse/pulse

# (cg) HAL support is no longer the default, and we don't officially support system wide, so
# System Wide + HAL is pretty unlikely.
rm -f %{buildroot}%{_sysconfdir}/dbus-1/system.d/%{name}-system.conf

# (cg) We require systemd now, so no point in using CK
rm -f %{buildroot}%{_libdir}/pulseaudio/modules/module-console-kit.so

# (cg) Disable x11-cork-request... it should be ahndled in the apps as we cannot
#      maintain state via this mechanism. Should be a patch, but I'm lazy.
sed -i 's,\(/usr/bin/pactl load-module module-x11-cork-request\),#\1,' %{buildroot}%{_bindir}/start-pulseaudio-x11

install -d -m 0755 %{buildroot}%{_userunitdir}/sockets.target.wants
ln -s ../%{name}.socket %{buildroot}%{_userunitdir}/sockets.target.wants/


%find_lang %{name}

%files -f %{name}.lang
%doc README
%license LICENSE GPL LGPL
%dir %{_sysconfdir}/pulse
%config(noreplace) %{_sysconfdir}/pulse/daemon.conf
%config(noreplace) %{_sysconfdir}/pulse/default.pa
%config(noreplace) %{_sysconfdir}/pulse/system.pa
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.*
%{_mandir}/man5/pulse-client.conf.5.*
%{_mandir}/man5/pulse-daemon.conf.5.*
%{_mandir}/man5/default.pa.5.*
%{_mandir}/man5/pulse-cli-syntax.5.*
%{_datadir}/icons/hicolor/*/*/*
%{_userunitdir}/%{name}.service
%{_userunitdir}/%{name}.socket
%{_userunitdir}/sockets.target.wants/%{name}.socket
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/alsa-mixer
%{_datadir}/dbus-1/system.d/pulseaudio-system.conf
%{_udevrulesdir}/90-pulseaudio.rules
%dir %{_libdir}/pulseaudio
%dir %{_libdir}/pulseaudio/modules
%{_libdir}/pulseaudio/modules/libalsa-util.so
%{_libdir}/pulseaudio/modules/libcli.so
%{_libdir}/pulseaudio/modules/libprotocol-cli.so
%{_libdir}/pulseaudio/modules/libprotocol-http.so
%{_libdir}/pulseaudio/modules/libprotocol-native.so
%{_libdir}/pulseaudio/modules/libprotocol-simple.so
%{_libdir}/pulseaudio/modules/libraop.so
%{_libdir}/pulseaudio/modules/librtp.so
%{_libdir}/pulseaudio/modules/libwebrtc-util.so
%{_libdir}/pulseaudio/modules/module-allow-passthrough.so
%{_libdir}/pulseaudio/modules/module-alsa-card.so
%{_libdir}/pulseaudio/modules/module-alsa-sink.so
%{_libdir}/pulseaudio/modules/module-alsa-source.so
%{_libdir}/pulseaudio/modules/module-always-sink.so
%{_libdir}/pulseaudio/modules/module-always-source.so
%{_libdir}/pulseaudio/modules/module-augment-properties.so
%{_libdir}/pulseaudio/modules/module-card-restore.so
%{_libdir}/pulseaudio/modules/module-cli-protocol-tcp.so
%{_libdir}/pulseaudio/modules/module-cli-protocol-unix.so
%{_libdir}/pulseaudio/modules/module-cli.so
%{_libdir}/pulseaudio/modules/module-combine.so
%{_libdir}/pulseaudio/modules/module-combine-sink.so
%{_libdir}/pulseaudio/modules/module-role-cork.so
%{_libdir}/pulseaudio/modules/module-systemd-login.so
%{_libdir}/pulseaudio/modules/module-dbus-protocol.so
%{_libdir}/pulseaudio/modules/module-detect.so
%{_libdir}/pulseaudio/modules/module-device-manager.so
%{_libdir}/pulseaudio/modules/module-device-restore.so
%{_libdir}/pulseaudio/modules/module-echo-cancel.so
%{_libdir}/pulseaudio/modules/module-hal-detect.so
%{_libdir}/pulseaudio/modules/module-http-protocol-tcp.so
%{_libdir}/pulseaudio/modules/module-http-protocol-unix.so
%{_libdir}/pulseaudio/modules/module-intended-roles.so
%{_libdir}/pulseaudio/modules/module-loopback.so
%{_libdir}/pulseaudio/modules/module-match.so
%{_libdir}/pulseaudio/modules/module-mmkbd-evdev.so
%{_libdir}/pulseaudio/modules/module-native-protocol-fd.so
%{_libdir}/pulseaudio/modules/module-native-protocol-tcp.so
%{_libdir}/pulseaudio/modules/module-native-protocol-unix.so
%{_libdir}/pulseaudio/modules/module-null-sink.so
%{_libdir}/pulseaudio/modules/module-null-source.so
%{_libdir}/pulseaudio/modules/module-pipe-sink.so
%{_libdir}/pulseaudio/modules/module-pipe-source.so
%{_libdir}/pulseaudio/modules/module-raop-sink.so
%{_libdir}/pulseaudio/modules/module-rygel-media-server.so
%{_libdir}/pulseaudio/modules/module-position-event-sounds.so
%{_libdir}/pulseaudio/modules/module-rescue-streams.so
%{_libdir}/pulseaudio/modules/module-rtp-recv.so
%{_libdir}/pulseaudio/modules/module-rtp-send.so
%{_libdir}/pulseaudio/modules/module-simple-protocol-tcp.so
%{_libdir}/pulseaudio/modules/module-simple-protocol-unix.so
%{_libdir}/pulseaudio/modules/module-sine.so
%{_libdir}/pulseaudio/modules/module-sine-source.so
%{_libdir}/pulseaudio/modules/module-tunnel-sink.so
%{_libdir}/pulseaudio/modules/module-tunnel-source.so
%{_libdir}/pulseaudio/modules/module-tunnel-sink-new.so
%{_libdir}/pulseaudio/modules/module-tunnel-source-new.so
%{_libdir}/pulseaudio/modules/module-udev-detect.so
%{_libdir}/pulseaudio/modules/module-volume-restore.so
%{_libdir}/pulseaudio/modules/module-virtual-sink.so
%{_libdir}/pulseaudio/modules/module-virtual-source.so
%{_libdir}/pulseaudio/modules/module-stream-restore.so
%{_libdir}/pulseaudio/modules/module-suspend-on-idle.so
%{_libdir}/pulseaudio/modules/module-default-device-restore.so
%{_libdir}/pulseaudio/modules/module-ladspa-sink.so
%{_libdir}/pulseaudio/modules/module-remap-sink.so
%{_libdir}/pulseaudio/modules/module-remap-source.so
%{_libdir}/pulseaudio/modules/module-switch-on-connect.so
%{_libdir}/pulseaudio/modules/module-filter-apply.so
%{_libdir}/pulseaudio/modules/module-filter-heuristics.so
%{_libdir}/pulseaudio/modules/module-virtual-surround-sink.so
%{_libdir}/pulseaudio/modules/module-switch-on-port-available.so
%{_libdir}/pulseaudio/modules/module-role-ducking.so

%files -n %{libname}
%{_libdir}/libpulse.so.%{major}{,.*}
%{_libdir}/libpulse-simple.so.%{major}{,.*}
%dir %{_libdir}/%{name}

%files -n %{corelibname}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libpulsecore-%{apiver}.so

%files -n %{commonlibname}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libpulsecommon-%{apiver}.so

%files client-config
%dir %{_sysconfdir}/pulse
%config(noreplace) %{_sysconfdir}/pulse/client.conf
%dir %{_sysconfdir}/sound/profiles/pulse
%{_sysconfdir}/sound/profiles/pulse/profile.conf
%{_sysconfdir}/sound/profiles/pulse/pulse

%files -n %{glib2libname}
%{_libdir}/libpulse-mainloop-glib.so.%{glib2major}{,.*}

%files -n %{libname_devel}
%{_libdir}/libpulse.so
%{_libdir}/libpulse-mainloop-glib.so
%{_libdir}/libpulse-simple.so
%dir %{_includedir}/pulse
%{_includedir}/pulse/*.h
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/PulseAudio
%{_datadir}/vala/vapi/libpulse.deps
%{_datadir}/vala/vapi/libpulse.vapi
%{_datadir}/vala/vapi/libpulse-mainloop-glib.deps
%{_datadir}/vala/vapi/libpulse-mainloop-glib.vapi
%{_datadir}/vala/vapi/libpulse-simple.deps
%{_datadir}/vala/vapi/libpulse-simple.vapi

%if !%bootstrap
%files module-bluetooth
%{_libdir}/pulseaudio/modules/libbluez5-util.so
%{_libdir}/pulseaudio/modules/module-bluetooth-discover.so
%{_libdir}/pulseaudio/modules/module-bluetooth-policy.so
%{_libdir}/pulseaudio/modules/module-bluez5-device.so
%{_libdir}/pulseaudio/modules/module-bluez5-discover.so
%endif

%files module-lirc
%{_libdir}/pulseaudio/modules/module-lirc.so

%files module-x11
%{_sysconfdir}/X11/xinit.d/50%{name}
%{_bindir}/pax11publish
%config(noreplace) %{_sysconfdir}/xdg/Xwayland-session.d/00-pulseaudio-x11
%{_userunitdir}/pulseaudio-x11.service
%{_bindir}/start-pulseaudio-x11
%{_mandir}/man1/pax11publish.1.*
%{_mandir}/man1/start-pulseaudio-x11.1.*
%{_libdir}/pulseaudio/modules/module-x11-bell.so
%{_libdir}/pulseaudio/modules/module-x11-cork-request.so
%{_libdir}/pulseaudio/modules/module-x11-publish.so
%{_libdir}/pulseaudio/modules/module-x11-xsmp.so
%{_sysconfdir}/xdg/autostart/pulseaudio.desktop

%files module-zeroconf
%{_libdir}/pulseaudio/modules/libavahi-wrap.so
%{_libdir}/pulseaudio/modules/module-zeroconf-discover.so
%{_libdir}/pulseaudio/modules/module-zeroconf-publish.so
%{_libdir}/pulseaudio/modules/module-raop-discover.so

%files module-jack
%{_libdir}/pulseaudio/modules/module-jack-sink.so
%{_libdir}/pulseaudio/modules/module-jack-source.so
%{_libdir}/pulseaudio/modules/module-jackdbus-detect.so

%if %{with gconf}
%files module-gconf
%{_libdir}/pulseaudio/modules/module-gconf.so
%dir %{_libexecdir}/pulse/
%{_libexecdir}/pulse/gconf-helper
%endif

%files module-gsettings
%{_libdir}/pulseaudio/modules/module-gsettings.so
%dir %{_libexecdir}/pulse/
%{_libexecdir}/pulse/gsettings-helper
%{_datadir}/GConf/gsettings/pulseaudio.convert
%{_datadir}/glib-2.0/schemas/org.freedesktop.pulseaudio.gschema.xml

%files module-equalizer
%{_bindir}/qpaeq
%{_libdir}/pulseaudio/modules/module-equalizer-sink.so

%files utils
%{_datadir}/bash-completion/completions/*
%{_datadir}/zsh/site-functions/_pulseaudio
%{_bindir}/pacat
%{_bindir}/pacmd
%{_bindir}/pactl
%{_bindir}/pamon
%{_bindir}/paplay
%{_bindir}/parec
%{_bindir}/parecord
%{_bindir}/pasuspender
%{_bindir}/pa-info
%{_mandir}/man1/pacat.1.*
%{_mandir}/man1/pacmd.1.*
%{_mandir}/man1/pactl.1.*
%{_mandir}/man1/pamon.1.*
%{_mandir}/man1/paplay.1.*
%{_mandir}/man1/parec.1.*
%{_mandir}/man1/parecord.1.*
%{_mandir}/man1/pasuspender.1.*


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 17.0-3.mga10
+ Revision: 2228689
- Mageia 10 Mass Rebuild

* Sun Oct 06 2024 wally <wally> 17.0-2.mga10
+ Revision: 2103907
- provide pulseaudio-libs-devel with devel pkg

* Mon Jan 29 2024 daviddavid <daviddavid> 17.0-1.mga10
+ Revision: 2036093
- new version: 17.0
- remove merged upstream patches

* Sun Mar 19 2023 ghibo <ghibo> 16.1-14.mga9
+ Revision: 1949690
- Add patch from upstream to not overwrite user configured default sink

* Tue Feb 28 2023 ghibo <ghibo> 16.1-13.mga9
+ Revision: 1945669
- merge patches from git upstream to detect rate before setting HW params.
- merge patch from git upstream to drop check for chunk index alignment.
- merge patch from git upstream to import Asus Xonar SE profile from pipewire.

* Thu Feb 16 2023 ghibo <ghibo> 16.1-12.mga9
+ Revision: 1943387
- more patches from git upstream (fix resempler oversized memblock)

* Sat Jan 28 2023 ghibo <ghibo> 16.1-11.mga9
+ Revision: 1936621
- Drop upstream alsa-ucm patchset (as is a mess on some AMD Renoir)

* Fri Jan 27 2023 ghibo <ghibo> 16.1-10.mga9
+ Revision: 1936505
- rebuild against fresh libalsa2.
- merge two patches from ubuntu (module-switch on connect and deferred-volume-safety-margin).

* Wed Jan 25 2023 ghibo <ghibo> 16.1-9.mga9
+ Revision: 1936203
- merge patches from git upstream (fix comma parsing in bluetooth, fix time underflow)

* Sat Dec 10 2022 ghibo <ghibo> 16.1-8.mga9
+ Revision: 1920267
- Merge more patches from git upstream (fix a crash when setting volume out of range).

* Mon Dec 05 2022 wally <wally> 16.1-7.mga9
+ Revision: 1918030
- loosen client-config's alsa-plugins-pulse-config requires to recomends to
  break circular dep preventing pipewire-alsa install (mga#21221)
- drop old and unneeded %%triggerin scriptlet

* Wed Nov 16 2022 ghibo <ghibo> 16.1-6.mga9
+ Revision: 1908043
- Merge patches from upstream (fix flac playback with s24 format)
- Revert BR to old webrtc-audio-processing
- Rebuild against webrtc-audio-processing1

* Wed Oct 26 2022 ghibo <ghibo> 16.1-5.mga9
+ Revision: 1899458
- Rebuild against fresh (mga9) libwebrtc-audio-processing

* Tue Oct 25 2022 ghibo <ghibo> 16.1-4.mga9
+ Revision: 1899254
- Rebuild against libalsa 1.2.8

* Mon Oct 24 2022 ghibo <ghibo> 16.1-3.mga9
+ Revision: 1898860
- Merge upstream patches

* Mon Oct 24 2022 ghibo <ghibo> 16.1-2.mga9
+ Revision: 1898855
- Fresh rebuild against latest libalsa package

* Mon Aug 29 2022 tv <tv> 16.1-1.mga9
+ Revision: 1881629
- 16.1

* Fri Mar 18 2022 tv <tv> 15.0-5.mga9
+ Revision: 1797993
- Fix library license
- Bootstrap: recommends instead of requires alsa-plugins-pulse-config

* Wed Mar 16 2022 tv <tv> 15.0-4.mga9
+ Revision: 1794998
- Drop conditionale for gconf as it was stripped in 15 (& rebuild with gcc12)

* Sat Oct 02 2021 wally <wally> 15.0-3.mga9
+ Revision: 1748397
- workaround RPATH issue
- rebuild for openssl 3.0.0

* Tue Aug 24 2021 ngompa <ngompa> 15.0-2.mga9
+ Revision: 1742453
- Add 'pulseaudio-daemon' Provides + Conflicts to support swapping with PipeWire

* Thu Jul 29 2021 tv <tv> 15.0-1.mga9
+ Revision: 1738133
- 15.0
- switch to meson
- gconf support is dead
- EsounD support will go out in next release so
  we might as well drop it now
+ wally <wally>
- own /usr/libexec/pulse directory also with module-gsettings pkg

* Mon Mar 08 2021 ghibo <ghibo> 14.2-4.mga9
+ Revision: 1700625
- Don't alter the SESSION env var content in a script to be "sourced", as this might interfere with subsequents scripts.

* Tue Mar 02 2021 ghibo <ghibo> 14.2-3.mga9
+ Revision: 1696324
- . Sometimes SESSION is achieved running chksession -F which might return Plasma or PlasmaMediaCenter. Add cases accordingly.

* Fri Feb 19 2021 ghibo <ghibo> 14.2-2.mga8
+ Revision: 1675610
- Fix pulseaudio.xinit to match newer startplasma-x11 in SESSSION

* Sun Jan 17 2021 luigiwalser <luigiwalser> 14.2-1.mga8
+ Revision: 1672200
- 14.2

* Wed Jan 13 2021 luigiwalser <luigiwalser> 14.1-1.mga8
+ Revision: 1671573
- 14.1

* Mon Nov 23 2020 tv <tv> 14.0-1.mga8
+ Revision: 1648802
- 14.0

* Mon Nov 02 2020 daviddavid <daviddavid> 13.99.3-1.mga8
+ Revision: 1641577
- new version: 13.99.3

* Sat Oct 31 2020 wally <wally> 13.99.2-2.mga8
+ Revision: 1640918
- fix build with autoconf > 2.69

* Wed Sep 23 2020 daviddavid <daviddavid> 13.99.2-1.mga8
+ Revision: 1629469
- new version: 13.99.2
- remove merged upstream patches

* Sun Jun 21 2020 wally <wally> 13.99.1-3.mga8
+ Revision: 1598358
- drop unneeded linker flag fix

* Fri Jun 19 2020 wally <wally> 13.99.1-2.mga8
+ Revision: 1597192
- workaround gcc10 multiple definition linking issue
+ daviddavid <daviddavid>
- backport some upstream patches to fix missing UCM mixers crash

* Fri Feb 21 2020 daviddavid <daviddavid> 13.99.1-1.mga8
+ Revision: 1548374
- new version: 13.99.1
- remove merged upstream patches

* Sun Feb 16 2020 daviddavid <daviddavid> 13.0-2.mga8
+ Revision: 1531801
- add upstream patch to switch qpaeq to python3
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Sep 14 2019 daviddavid <daviddavid> 13.0-1.mga8
+ Revision: 1440644
- new version: 13.0

* Sun Sep 01 2019 daviddavid <daviddavid> 12.99.3-1.mga8
+ Revision: 1436151
- new version: 12.99.3

* Wed Aug 07 2019 tv <tv> 12.99.2-6.mga8
+ Revision: 1428082
- new release

* Sat Aug 03 2019 daviddavid <daviddavid> 12.99.1-6.mga8
+ Revision: 1427073
- port equalizer module to PyQt5 and Python3

* Sat Aug 03 2019 daviddavid <daviddavid> 12.99.1-5.mga8
+ Revision: 1427068
- new version: 12.99.1

* Sun Mar 03 2019 wally <wally> 12.2-5.mga7
+ Revision: 1371121
- drop gconf support pkg and replace it with gsettings

* Mon Dec 17 2018 barjac <barjac> 12.2-4.mga7
+ Revision: 1342281
- Fix update path by obsoleting an installed pulseaudio-module-gconf

* Wed Dec 12 2018 barjac <barjac> 12.2-3.mga7
+ Revision: 1340646
- Added conflict between gsettings and gconf modules
- part of fix for Mga#23963 (paprefs does not start)

* Sun Sep 23 2018 umeabot <umeabot> 12.2-2.mga7
+ Revision: 1300404
- Mageia 7 Mass Rebuild

* Sun Aug 19 2018 daviddavid <daviddavid> 12.2-1.mga7
+ Revision: 1252757
- new version: 12.2

* Fri Jun 22 2018 tv <tv> 12.0-2.mga7
+ Revision: 1238745
- remove obsolete requires on libltdl
- remove obsolete requires on udev
- BR gtk3-devel
- disable OSS output (we only suport ALSA for years)
- remove BR on samplerate (deprecated)

* Thu Jun 21 2018 tv <tv> 12.0-1.mga7
+ Revision: 1238643
- new release
- new pulseaudio-module-gsettings subpkg
- drop module-xen subpkg
- BR pkgconfig(soxr) & pkgconfig(speexdsp)
- drop merged patches
- rediff 2 patches

* Sat May 26 2018 tv <tv> 11.1-2.mga7
+ Revision: 1232302
- fix build with glibc-2.27 (but we'd better update PA)
+ ovitters <ovitters>
- disable ofono support as 1) not packaged 2) seems unmaintained

* Wed Nov 29 2017 barjac <barjac> 11.1-1.mga7
+ Revision: 1180189
- patches added to fix Mga#22091
- (pulseaudio module-device-manager mis-routes streams in plasma5)
+ ghibo <ghibo>
- Update to release 11.1.

* Tue Sep 05 2017 tv <tv> 11.0-3.mga7
+ Revision: 1151487
- new release

* Sat Aug 05 2017 neoclust <neoclust> 10.0-3.mga7
+ Revision: 1136106
- Disable flat_volume ( should fix mga#21284 )

* Fri Aug 04 2017 guillomovitch <guillomovitch> 10.0-2.mga7
+ Revision: 1134967
- rebuild for latest openssl

* Tue Feb 28 2017 ghibo <ghibo> 10.0-1.mga6
+ Revision: 1088196
- New release: 10.0.
- Disable RAOP2 patches for now as not merging correctly.
+ ovitters <ovitters>
- remove esd from description
+ tv <tv>
- greatly simplify patch 500

* Wed Dec 21 2016 ghibo <ghibo> 9.0-5.mga6
+ Revision: 1076255
- Remove icewm from XDG session list (spotted by Olaf Vitters).

* Wed Dec 21 2016 ghibo <ghibo> 9.0-4.mga6
+ Revision: 1076241
- Fix pulseaudio.xinit because the $SESSION env var, when called from sddm
  contains the Exec argument of the .desktop file, and thus fails the check against
  the previous generic session names like "KDE", "GNOME", etc.; add further
  sessions check names for the case of desktop where xdg autostart already
  starts pulseaudio correctly and automatically.
- pulseaudio.xinit: add an extra check on pulseaudio pid (for when it's not started from xdg
  autostart) and for when, sometimes, start-pulseaudio-x11 fails.
- pulseaudio.xinit: execute the /etc/sysconfig/pulseaudio config file that already exists.

* Wed Sep 21 2016 daviddavid <daviddavid> 9.0-3.mga6
+ Revision: 1054837
- add missing dependencies for module-equalizer subpackage (mga#19429)

* Fri Aug 26 2016 pterjan <pterjan> 9.0-2.mga6
+ Revision: 1049000
- Fix file list on arm

* Wed Aug 24 2016 luigiwalser <luigiwalser> 9.0-1.mga6
+ Revision: 1048260
- 9.0

* Thu May 12 2016 tv <tv> 8.0-5.mga6
+ Revision: 1014235
- adjust file list on ARM

* Thu May 12 2016 luigiwalser <luigiwalser> 8.0-4.mga6
+ Revision: 1013925
- use upstream patch to fix build with webrtc-audio-processing 0.2
- rebuild for webrtc-audio-processing

* Sun Apr 03 2016 tv <tv> 8.0-3.mga6
+ Revision: 997799
- rebuild for new xen

* Sat Mar 19 2016 luigiwalser <luigiwalser> 8.0-2.mga6
+ Revision: 993021
- fix patch 605

* Thu Feb 11 2016 colin <colin> 8.0-1.mga6
+ Revision: 955534
- Fix release

* Thu Feb 11 2016 colin <colin> 8.0-0.1.mga6
+ Revision: 954401
- New version: 8.0
+ tv <tv>
- drop support for ia64
- switch to pkgconfig() BRs

* Thu Sep 24 2015 colin <colin> 7.0-1.mga6
+ Revision: 883009
- New version: 7.0

* Wed Sep 16 2015 blino <blino> 6.0-2.mga6
+ Revision: 879876
- add Apple AirPlay2/RAOP2 support (patches from pulseaudio-raop2 project)

* Wed Jul 08 2015 colin <colin> 6.0-1.mga6
+ Revision: 852733
- New version: 6.0

* Tue Feb 03 2015 akien <akien> 5.0-6.mga5
+ Revision: 813309
- Rebuild for new xen

* Sun Oct 19 2014 colin <colin> 5.0-5.mga5
+ Revision: 791791
- Switch to systemd for launching PA via socket activation (hopefully solve some login delays)

* Wed Oct 15 2014 umeabot <umeabot> 5.0-4.mga5
+ Revision: 749712
- Second Mageia 5 Mass Rebuild
+ tv <tv>
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 5.0-3.mga5
+ Revision: 687834
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
- s/uggests:/Recommends:/

* Wed Sep 03 2014 joequant <joequant> 5.0-2.mga5
+ Revision: 671640
- rebuild with new systemd

* Sun Jul 06 2014 fwang <fwang> 5.0-1.mga5
+ Revision: 650149
- 5.0 final

* Thu Jan 09 2014 colin <colin> 5.0-0.20131220.2.mga4
+ Revision: 565776
+ rebuild (emptylog)

* Fri Dec 20 2013 colin <colin> 5.0-0.20131220.1.mga4
+ Revision: 559066
- Update snapshot

* Tue Oct 22 2013 umeabot <umeabot> 5.0-0.20131010.3.mga4
+ Revision: 545576
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 colin <colin> 5.0-0.20131010.2.mga4
+ Revision: 501426
- Add latest upstream fixes

* Fri Oct 11 2013 colin <colin> 5.0-0.20131010.1.mga4
+ Revision: 495244
- Switch to PA 5.0 git for bluez 5 support
- Drop speex-fixed-0 resampler patch - upstream now uses speex-fixed-1

* Sun Jul 14 2013 boklm <boklm> 4.0-2.mga4
+ Revision: 454276
- Add pulseaudio-utils as require on pulseaudio-module-x11
  (pactl is needed by start-pulseaudio-x11)

* Tue Jun 04 2013 colin <colin> 4.0-1.mga4
+ Revision: 437157
- Remove the --disable-hal option - it's gone.
- Switch to pkgconfig requires for X11 stuff
- New version: 4.0
- Drop cherry-picked patches
- Drop json-c name patch (fixed also upstream)

* Sun Jan 13 2013 umeabot <umeabot> 3.0-7.mga3
+ Revision: 378310
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 10 2013 colin <colin> 3.0-6.mga3
+ Revision: 344640
- Rebuild for new xen

* Thu Jan 03 2013 neoclust <neoclust> 3.0-5.mga3
+ Revision: 338056
- Fix file list after libexec changes

* Thu Dec 27 2012 rtp <rtp> 3.0-4.mga3
+ Revision: 335678
- disable neon on arm as the targets don't have neon

* Thu Dec 20 2012 oden <oden> 3.0-3.mga3
+ Revision: 333448
- fix build
- rebuilt for new json-c libs

* Wed Dec 19 2012 colin <colin> 3.0-2.mga3
+ Revision: 332798
- Fix speaker+headphone ports on some h/w.
- Drop an unneeded patch now that kernel supports Phantom Jacks.

* Tue Dec 18 2012 colin <colin> 3.0-1.mga3
+ Revision: 332499
- New version: 3.0

* Thu Dec 13 2012 colin <colin> 2.99.3-1.mga3
+ Revision: 330111
- New version: 2.99.3 (3.0 RC)

* Tue Oct 16 2012 colin <colin> 2.1-6.mga3
+ Revision: 307279
- Enable webrtc echo canceller

* Wed Oct 10 2012 rtp <rtp> 2.1-5.mga3
+ Revision: 304289
- Enable Xen module only on arches with Xen support

* Thu Sep 27 2012 colin <colin> 2.1-4.mga3
+ Revision: 298651
- Fix RPM Groups (might need refinement)
- Remove patch that is no longer needed with latest systemd.

* Wed Sep 05 2012 colin <colin> 2.1-3.mga3
+ Revision: 288289
- Allow idle exit when all user sessions are closing (avoids session deadlock)

* Fri Aug 24 2012 colin <colin> 2.1-2.mga3
+ Revision: 283680
- Switch to systemd-logind for session management (goodbye console-kit)

* Tue Jul 24 2012 colin <colin> 2.1-1.mga3
+ Revision: 274077
- New version: 2.1

* Sat Jul 07 2012 kamil <kamil> 2.0-5.mga3
+ Revision: 268617
- rebuild against new libatomic_opt

* Sat Jun 30 2012 colin <colin> 2.0-4.mga3
+ Revision: 265465
- Cherry pick patch for compatibility with latest udev

* Fri Jun 29 2012 colin <colin> 2.0-3.mga3
+ Revision: 264947
- Rebuild against new libudev major

* Sat Jun 23 2012 wally <wally> 2.0-2.mga3
+ Revision: 262754
- don't own icons directories

* Sat May 12 2012 colin <colin> 2.0-1.mga2
+ Revision: 235384
- New version: 2.0

* Wed Mar 28 2012 colin <colin> 1.99.2-1.mga2
+ Revision: 227360
- New version: 1.99.2 (2.0 RC2)

* Mon Mar 12 2012 colin <colin> 1.98-0.275.1.mga2
+ Revision: 223043
- New version: 1.98 (2.0 pre-release)
- Split common and core libs to separate packages
- Add -xen subpackage for xen paravirtualized audio support.
- Remove obsolete obsoletes (pre mdv2010.2)
- Obsolete pulsezeroconf lib for smoother upgrade

* Sat Dec 10 2011 eatdirt <eatdirt> 1.1-3.mga2
+ Revision: 180456
- Rebuilt for fftw-3.3

* Mon Nov 28 2011 colin <colin> 1.1-2.mga2
+ Revision: 173851
- Own the version-specifi API libdir to allow for less cluttered upgrades
+ eatdirt <eatdirt>
- client-config now requires alsa-plugins-pulse-config (#bug 2966)

* Thu Oct 20 2011 colin <colin> 1.1-1.mga2
+ Revision: 156876
- New version: 1.1

* Fri Oct 14 2011 colin <colin> 1.0-2.mga2
+ Revision: 155080
- Update to the latest upstream stable-1.x branch

* Tue Sep 27 2011 colin <colin> 1.0-1.mga2
+ Revision: 149319
- New version: 1.0

* Thu Sep 15 2011 colin <colin> 0.99.4-1.mga2
+ Revision: 143995
- New version: 0.99.4 (RC4)

* Sun Sep 04 2011 colin <colin> 0.99.3-2.mga2
+ Revision: 138389
- Apply various upstream fixes

* Mon Aug 29 2011 colin <colin> 0.99.3-1.mga2
+ Revision: 136181
- New version: 0.99.3 (RC3)
- Update to PulseAudio 0.99.2 (1.0 test 2)
- Some more upstream fixes
- Add a few upstream fixes
- Add more BR that I missed
- Add BR for libjson-devel
- Update to PulseAudio 0.99.1 (1.0 test 1)

* Thu Jun 23 2011 colin <colin> 0.9.23-1.mga2
+ Revision: 112863
- New version: 0.9.23

* Sun Apr 24 2011 colin <colin> 0.9.22-5.mga1
+ Revision: 90166
- Update to latest stable-queue (soon to be 0.9.23)

* Fri Feb 25 2011 colin <colin> 0.9.22-4.mga1
+ Revision: 59475
- Latest upstream patches relating to combine, rtp and loopback module timing improvements

* Mon Feb 14 2011 colin <colin> 0.9.22-3.mga1
+ Revision: 51778
- Disable bootstrapping - we're good to go now
- Add the latest upstream stable-queue patches.
- imported package pulseaudio
+ rtp <rtp>
- disable armv6-only asm on armv5te (backport from upstream git)
+ blino <blino>
- jack has been moved out of bootstrap, enable sub-package
+ dmorgan <dmorgan>
- Remove libjack-devel and lirc-devel from the bootstrap
- add lirc-devel in the boostrap
- add libjack-devel in the boostrap
- Remove mdv macros
  Bootstrap PA


* Thu Dec 02 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 0.9.22-2mdv2011.0
+ Revision: 605034
- Replace X11-devel BR for proper ones, saving 71 BuildRequirements

* Fri Nov 26 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.22-1mdv2011.0
+ Revision: 601427
- New version: 0.9.22

* Thu Nov 18 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-34mdv2011.0
+ Revision: 598514
- Latest batch of fixes from the upstream stable-queue

* Wed Sep 29 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-33mdv2011.0
+ Revision: 582098
- Push some patches upstream
- Remove useless patch to protect against a case that is cheacked earlier

* Sat Sep 18 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-32mdv2011.0
+ Revision: 579511
- Fix some segfaults with XCB support

* Wed Sep 15 2010 Funda Wang <fwang@mandriva.org> 0.9.21-31mdv2011.0
+ Revision: 578527
- rebuild for missing packages

* Wed Sep 15 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-30mdv2011.0
+ Revision: 578505
- Remove apparently bogus build dep on liboil
- Latest batch of fixes from upstream stable-queue

* Tue Aug 31 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-29mdv2011.0
+ Revision: 574619
- Upstream patch to fix recording timings after starting corked

* Sun Aug 15 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-28mdv2011.0
+ Revision: 570251
- Fix udev hex decoding and reorganise patches a bit.

* Thu Jul 15 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-27mdv2011.0
+ Revision: 553539
- Fix assertion on mmap write with a52 alsa plugin
- Disable rewinds when using ALSA plugins (i.e. a52)
- Convert the libpulse X11 code to XCB

* Wed Jun 09 2010 Raphaël Gertz <rapsys@mandriva.org> 0.9.21-27mdv2010.1
+ Revision: 547306
- Add sysconfig/pulseaudio config merge
- Add default.pa config merge

* Sat Jun 05 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-26mdv2010.1
+ Revision: 547134
- Fix initial device order under KDE (should fix HDMI being default rather than internal speakers)

* Sun May 09 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.9.21-25mdv2010.1
+ Revision: 544107
- bump rel and resubmit due to missing packages

  + Colin Guthrie <cguthrie@mandriva.org>
    - Latest patches from stable-queue, including potential rtp fix.

* Tue Apr 27 2010 Christophe Fergeau <cfergeau@mandriva.com> 0.9.21-23mdv2010.1
+ Revision: 539593
- rebuild so that shared libraries are properly stripped again

* Sat Apr 17 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-22mdv2010.1
+ Revision: 535910
- Fix issue when IPv6 is disabled in the kernel

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - xfce4 support XDG autostart too

* Mon Apr 05 2010 Funda Wang <fwang@mandriva.org> 0.9.21-21mdv2010.1
+ Revision: 531734
- rebuild for new openssl

* Wed Mar 17 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-20mdv2010.1
+ Revision: 524316
- Do not use monitors for intended roles (fixes issue of skype picking playback monitors for headsets)

* Mon Mar 15 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-19mdv2010.1
+ Revision: 519434
- Fix jack-related crash on jackd shutdown

* Fri Mar 12 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-18mdv2010.1
+ Revision: 518310
- Add support for Digital Mic as found in some Dell netbooks

* Thu Mar 11 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-17mdv2010.1
+ Revision: 518233
- Disable HAL support (note: module-hal-detect.so is still included but it now just loads udev-detect)
- One more fix from stable-queue

* Fri Feb 26 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-16mdv2010.1
+ Revision: 511797
- One final patch from stable-queue (for a while)

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 0.9.21-15mdv2010.1
+ Revision: 511626
- rebuilt against openssl-0.9.8m

* Tue Feb 23 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-14mdv2010.1
+ Revision: 510184
- More stable-queue fixes

* Mon Feb 22 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-13mdv2010.1
+ Revision: 509331
- More stable-queue fixes
- Obsolete esound-daemon

* Fri Feb 19 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-12mdv2010.1
+ Revision: 507982
- Latest fixes from stable-queue

* Fri Feb 12 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-11mdv2010.1
+ Revision: 504388
- Fix paplay deadlock

* Wed Feb 10 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-10mdv2010.1
+ Revision: 503480
- Add a fix for missing sink input proplist changes.

* Fri Feb 05 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-9mdv2010.1
+ Revision: 501132
- Make sure routing is reapplied if a save_sink|source flag is cleared.

* Fri Feb 05 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-8mdv2010.1
+ Revision: 501028
- Reset the save_sink flag if the device in the stream restore db is reset
- Make the property searching code work generically for all subfolders not just kde4

* Fri Jan 29 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-6mdv2010.1
+ Revision: 497860
- Look for .desktop files for KDE apps too (for stream icons)

* Mon Jan 18 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-5mdv2010.1
+ Revision: 492917
- More upstream fixes on the stable-queue branch

* Thu Jan 14 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-4mdv2010.1
+ Revision: 491556
- Include patches from the latest upstream stable-queue branch

* Mon Jan 04 2010 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-3mdv2010.1
+ Revision: 486233
- Fix for some Audigy cards
- Include Ubuntu fix for possible div-by-zero (not sure this has been reported but harmless patch)

* Mon Dec 28 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-2mdv2010.1
+ Revision: 483039
- Add upstream patch to mark some variables as volatile to fix threading issues.

* Mon Nov 23 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.21-1mdv2010.1
+ Revision: 469219
- New version: 0.9.21
- Dropped upstream applied patches

* Tue Nov 17 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.20-2mdv2010.1
+ Revision: 466708
- Fix missing alsa path config files

* Sat Nov 14 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.20-1mdv2010.1
+ Revision: 466074
- New bugfix version: 0.9.20
- Drop backported patch no longer needed

* Thu Nov 05 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.19-8mdv2010.1
+ Revision: 460436
- Re-enable libasyncns (previous problems should all be gone now)
- Fix SIMD stuff properly with upstream fix (MMX performance boost)

* Wed Oct 21 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.19-7mdv2010.0
+ Revision: 458495
- Disable MMX volume code as it appears to cause problems (mdv#53870)
- Remove old debugging patch which is no longer needed.
- Add a suggests on the alsa plugin from the library

* Tue Oct 20 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.19-6mdv2010.0
+ Revision: 458360
- Add suggests on the 32-bit library on 64-bit systems for better compatibility OOTB

* Sun Oct 18 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.19-5mdv2010.0
+ Revision: 458106
- Disable x11-cork-request module (can cause unpause after phone calls etc)

* Sat Oct 10 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.19-4mdv2010.0
+ Revision: 456560
- Minor update to module-device-manager to report device indexes instead of simple 'available' flag.

* Sat Oct 03 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.19-3mdv2010.0
+ Revision: 453183
- Latest version of device-manager
-  o Now plays nicely with module-stream-restore (individial apps can be moved)
-  o Now tracks a device description until the user specifically changes it.

* Fri Oct 02 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.19-2mdv2010.0
+ Revision: 452431
- Fix a couple typos in the device-manager stuff
- Customise the KDE related scripts to ensure they comply with our config.
- Update device-manager patch (now supports live routing with KDE)
- Obsolete libflashsupport here rather than in task-pulseaudio to easy upgrades.

* Wed Sep 30 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.19-1mdv2010.0
+ Revision: 451187
- New version: 0.9.19 (minor bugfilx rollup)

* Mon Sep 28 2009 Olivier Blin <oblin@mandriva.com> 0.9.18-6mdv2010.0
+ Revision: 450310
- add bootstrap to break circular build-dep chain:
  gst-plug-base->theora->SDL->libpulseaudio-devel->bluez-devel->gst-plug-base-dev
  choose to fix it here as it's easy and pulse is quicker to build
  than SDL (from Arnaud Patard)

* Sun Sep 27 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.18-5mdv2010.0
+ Revision: 449811
- Require update-alternatives for the client-config %%post script
- Move ccp command to end of %%post script just in case it fails (update-alternatives is more important)
- Update device-manager patch to current version

* Wed Sep 23 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.18-4mdv2010.0
+ Revision: 447868
- Proper fix for mmx/sse register starvation on some 32bit systems (mdv#53870)

* Mon Sep 21 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.18-3mdv2010.0
+ Revision: 446734
- Revert latest mmx optimisation as it appears to cause distortion (mdv#53870)

* Sun Sep 20 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.18-2mdv2010.0
+ Revision: 445922
- Fix tunnels to/from PA servers v0.9.16+
- Update device-manager branch to my latest version (not yet activated by default)

* Sat Sep 19 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.18-1mdv2010.0
+ Revision: 444655
- New version 0.9.18

* Fri Sep 18 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.17-2mdv2010.0
+ Revision: 444266
- Fix avahi detection of pulse/raop sinks
- Fix raop command writing
- Give all ports a human name to allow GUI tools to work properly and provide selection
- NB: All patches now pushed to 0.9.17-stable branch upstream

* Sun Sep 13 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.17-1mdv2010.0
+ Revision: 438812
- New version 0.9.17 (fixes non-timer based scheduling properly)

* Thu Sep 10 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-2mdv2010.0
+ Revision: 436824
- Revert a last minute change before 0.9.16 which I think is causing mdv#53589
- Drop old patches that should have been removed a while back.

* Thu Sep 10 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-1mdv2010.0
+ Revision: 436497
- New version: 0.9.16

* Thu Sep 10 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090909.2mdv2010.0
+ Revision: 436170
- Update to new git master with more fixes (hopefully) for mdv#52345

* Wed Sep 09 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090909.1mdv2010.0
+ Revision: 434942
- Update to 71e066c873e in order to help trace mdv#52763 and mdv#52345

* Tue Sep 08 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090908.2mdv2010.0
+ Revision: 433939
- Add some debugging to udev-detect to help trace mdv#52763 and mdv#52345

* Tue Sep 08 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090908.1mdv2010.0
+ Revision: 433151
- New snapshot

* Thu Sep 03 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090903.1mdv2010.0
+ Revision: 428006
- New snapshot including MMX/SSE fixes

* Wed Sep 02 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090902.1mdv2010.0
+ Revision: 424470
- New snapshot including some fixes that deal gracefully with Skypes invalid requests

* Mon Aug 31 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090831.1mdv2010.0
+ Revision: 422865
- New snapshot. Seems to address some flat volume issues.

* Thu Aug 27 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090827.1mdv2010.0
+ Revision: 421787
- New snapshot

* Tue Aug 25 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090824.1mdv2010.0
+ Revision: 420652
- Remove the system wide dbus policy file as neither is really supported fully any more
- New snapshot

* Thu Aug 20 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090819.1mdv2010.0
+ Revision: 418340
- New snapshot - flat volume logic tweaks which should address mdv#52881 and maybe mdv#52918
- Daemon should no longer be setuid since rt-kit came along

* Tue Aug 18 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090817.1mdv2010.0
+ Revision: 417855
- Spec cleanup to remove old code (backporting is no longer supported due to kernel/udev requirements)
- New snapshot
 - Use ccp to merge config files on upgrade

* Sun Aug 16 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090816.1mdv2010.0
+ Revision: 416910
- New snapshot.
- Support soundprofiles

* Wed Aug 05 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090805.1mdv2010.0
+ Revision: 410096
- New snapshot (equiv to test4)

* Fri Jul 31 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090731.1mdv2010.0
+ Revision: 405158
- New snapshot.

* Thu Jul 23 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.20090723.1mdv2010.0
+ Revision: 399098
- New snapshot
- Build against polkit rather than policykit

* Thu Jul 02 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.test2.1mdv2010.0
+ Revision: 391824
- New version 0.9.16-test2

* Sun Jun 28 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.test1.2mdv2010.0
+ Revision: 390199
- Fix issue when retrieving device info from older servers
 - Add my history patches which includes a module-device-manager module (not activated by default)

* Fri Jun 26 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.16-0.test1.1mdv2010.0
+ Revision: 389301
- BuildRequires udev-devel
- Require specific udev version to save potential problems
- Rejig patches (remove the gap left by policy kit patch which is no longer used)
- New version 0.9.16-test1
 - New detection code based on udev
 - New intended roles module for automatic routing for certain roles

* Mon Jun 08 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-7mdv2010.0
+ Revision: 384150
- Drop SHM patch - it breaks.
- Apply two additional patches from upstream to fix missing function and debug verboseness

* Mon Jun 08 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-6mdv2010.0
+ Revision: 384094
- Add recommended backported patches from upstream

* Mon Jun 08 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-5mdv2010.0
+ Revision: 383797
- Apply upstream fix for mute status bug (mdv#51234)
- Use %%apply_patches macro

* Sat May 09 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-4mdv2010.0
+ Revision: 373751
- Revert a potentially problem upstream commit that interferes with Skype. mdv#49947

* Fri May 08 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-3mdv2010.0
+ Revision: 373419
- Backport some upstream fixes (mostly for 24/32bit sample formats)

* Tue Apr 21 2009 Frederic Crozat <fcrozat@mandriva.com> 0.9.15-2mdv2009.1
+ Revision: 368490
- Patch504 (Ubuntu): start PA earlier under GNOME (Mdv bug #47594)

* Tue Apr 14 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-1mdv2009.1
+ Revision: 366878
- New version: 0.9.15

* Fri Apr 10 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090410.1mdv2009.1
+ Revision: 365737
- New snapshot (test8 - probably final rc)

* Wed Apr 01 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090401.2mdv2009.1
+ Revision: 363404
- Update to slightly newer snapshot to fix bt module loading

* Wed Apr 01 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090401.1mdv2009.1
+ Revision: 363124
- New test version (test7)

* Fri Mar 06 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090305.1mdv2009.1
+ Revision: 349715
- New snapshot: 0.9.15-test5

* Mon Mar 02 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090302.1mdv2009.1
+ Revision: 347524
- New snapshot

* Sun Mar 01 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090225.3mdv2009.1
+ Revision: 346329
- Fix alsa when not using real cards

* Thu Feb 26 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090225.2mdv2009.1
+ Revision: 345065
- Fix bluetooth device module linking

* Thu Feb 26 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090225.1mdv2009.1
+ Revision: 345031
- New snapshot (test3 release)

* Sun Feb 22 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090222.1mdv2009.1
+ Revision: 343912
- New snapshot
- Add patch to fix trademark issues
- Add patch to include the moduledir in pkg-config file

* Thu Feb 12 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090212.1mdv2009.1
+ Revision: 339869
- New snapshot (test2 tarball equiv)

* Thu Feb 05 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090204.2mdv2009.1
+ Revision: 337683
- Disable module-position-event-sounds until it's fixed

* Wed Feb 04 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090204.1mdv2009.1
+ Revision: 337550
- New snapshot
- Remove patches merged upstream

* Wed Feb 04 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.15-0.20090203.1mdv2009.1
+ Revision: 337226
- Fix link ordering issues
- Reenable parallel build
- Fix up airtunes volume handling a bit
- Disable parallel make
- New snapshot
- Drop patches merged upstream
- Rediff remaining patches
- Temporarily disable module-stream-restore until pavucontrol is fixed

* Wed Jan 28 2009 Götz Waschk <waschk@mandriva.org> 0.9.14-0.20090109.2mdv2009.1
+ Revision: 335004
- fix build deps
- build with libtool 2.2 on Cooker

* Sat Jan 10 2009 Colin Guthrie <cguthrie@mandriva.org> 0.9.14-0.20090109.1mdv2009.1
+ Revision: 327831
- Revert upstream libtool 2.2 changes until we upgrade to libtool 2.2 ourselves
- Drop patch505 now fixed correctly upstream
- Drop gconf moving patch shouldn't be needed anymore (but need to test)
- New snapshot

* Wed Nov 05 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.14-0.20081105.1mdv2009.1
+ Revision: 300155
- New snapshot
- Add patch to fix/workaround module-suspend-on-idle
- Add patch to fix linking on pacmd

* Sat Oct 25 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.14-0.20081025.2mdv2009.1
+ Revision: 297232
- Fix packaging idiocy

* Sat Oct 25 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.14-0.20081025.1mdv2009.1
+ Revision: 297163
- Update to latest snapshot
- Rediff patches
- Drop upstream applied patches
- Reorganise spec due to upstream library/module changes

* Sat Oct 11 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.13-2mdv2009.1
+ Revision: 292505
- Fix broken tunnels

* Sat Oct 11 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.13-1mdv2009.1
+ Revision: 291919
+ rebuild (emptylog)

* Sun Sep 28 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.10-11mdv2009.0
+ Revision: 289064
- Fix some minor errors in the pid file robustness patch merged previously

* Mon Sep 22 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.10-10mdv2009.0
+ Revision: 287082
- Disable hotplug sound (it interferes with too many other subsystems)

* Sat Sep 20 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.10-9mdv2009.0
+ Revision: 286131
- Add a pulseaudio icon

* Thu Aug 14 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.10-8mdv2009.0
+ Revision: 271797
- Add backport of a PID file robustness patch (backport by OpenSuse)

* Tue Aug 05 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.10-7mdv2009.0
+ Revision: 264095
- Rejig specfile to use git to manage both our patches and upstream cherrypicks
- Cherry pick upstream commit to fix padsp ioctl issue.

* Sun Aug 03 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.10-6mdv2009.0
+ Revision: 262568
- Updates airtunes patch to fix linking

* Mon Jul 28 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.10-5mdv2009.0
+ Revision: 251886
- Add my patch to support Apple Airtunes
- Build against libasyncns

* Thu Jul 24 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.11-0.1mdv2009.0
+ Revision: 245568
+ rebuild (emptylog)

* Mon Jul 07 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.10-4mdv2009.0
+ Revision: 232372
- rebuilt against new libcap

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon Jun 09 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.10-3mdv2009.0
+ Revision: 217172
- Fix an issue in my previous patch that invalidated the cookie even tho' a valid one was read via x11 props

* Tue Jun 03 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.10-2mdv2009.0
+ Revision: 214826
- Really fix underlinking - libpulsecore.la is not available to libpulsedsp.so
- Fix underlinking
- Allow default devices set in pavucontrol to work across sessions (mdv#41224)
- Allow client.conf to take precedence over x11 properties of the root window (mdv#41224)
- Fix release

* Tue Apr 08 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.10-0.2mdv2009.0
+ Revision: 192376
- Drop patches applied or impelmented in different ways upstream.
- Adapt our default policy changes to new upstream version
- Drop PID file handling in scripts as it is handled in PA since 0.9.8
- New version 0.9.10

* Wed Mar 26 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.9-7mdv2008.1
+ Revision: 190283
- Add a new module to ensure that an sink always exists (even if it is a null-sink)

* Sat Feb 23 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.9-6mdv2008.1
+ Revision: 174076
- Fix an error when moving a record stream (no gui method for this) PA#244

* Fri Feb 15 2008 Frederic Crozat <fcrozat@mandriva.com> 0.9.9-5mdv2008.1
+ Revision: 168830
- Switch to speex-float-0, all "fixed" variants are adding "scratch" to Ia Ora startup sound

* Wed Feb 13 2008 Frederic Crozat <fcrozat@mandriva.com> 0.9.9-4mdv2008.1
+ Revision: 167040
- Patch12: change resample to speex-fixed-0 (Mdv bug #36084)

* Wed Feb 13 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.9-3mdv2008.1
+ Revision: 166890
- Add in an esd.conf in the esound-compat package to fix #37649

* Tue Feb 05 2008 Frederic Crozat <fcrozat@mandriva.com> 0.9.9-2mdv2008.1
+ Revision: 162667
- Update patch3 to move X11 module load after GConf module (fix enabling network sound server with paprefs not advertised in X atom)
- Patch11 (Debian): allow GConf module load to fail silently

* Thu Jan 24 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.9-1mdv2008.1
+ Revision: 157459
- Update to 0.9.9 to fix CVE-2008-0008 (only change is r2100 from PA SVN)
- Update padsp patch with extra checks on debug calls where appropriate.

* Tue Jan 15 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.8-13mdv2008.1
+ Revision: 152142
- Updated padsp patch from Spuk (thanks :))
- Fix MDV#36164 (upgrade issues due to spec reorganisation)
- Hopefully fix MDV#36750 (amsn crashing).

* Sat Jan 12 2008 Colin Guthrie <cguthrie@mandriva.org> 0.9.8-12mdv2008.1
+ Revision: 149735
- Hopefully fix MDV#36643 (PA#215) by changing the order env vars are checked

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Dec 21 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.8-11mdv2008.1
+ Revision: 136071
- Update tunnel patch to implement newer protol more fully
- Add patch to allow tunnels from 0.9.7<->0.9.8 by not sending new commands on old protocol.

* Wed Dec 19 2007 Frederic Crozat <fcrozat@mandriva.com> 0.9.8-10mdv2008.1
+ Revision: 134758
- Remove patch6, Ia Ora sound samples are small enough now

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Dec 14 2007 Frederic Crozat <fcrozat@mandriva.com> 0.9.8-9mdv2008.1
+ Revision: 120217
- Patch7: change policy to allow high priority and refuse realtime
- Autostart PA daemon under GNOME with xinit script too

* Wed Dec 12 2007 Frederic Crozat <fcrozat@mandriva.com> 0.9.8-8mdv2008.1
+ Revision: 117850
- Fix esound dependencies
- Enable parallel build
- Clean specfile

* Sat Dec 08 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.8-7mdv2008.1
+ Revision: 116535
- Provide/Obsolete esound
- Remove global esd socket path patch (libesound has been patched)

* Thu Dec 06 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.8-6mdv2008.1
+ Revision: 116073
- Increase (temporarily?) sample cache size to cope with Ia Ora sound files.
- Regenerate configure after patch4
- Add an xinit.d file to start for non-Gnome desktops
- Add some mandriva customisations to esdcompat to make it work like xinit.d file
- Do not fail when trying to load pa with the x11 module installed but when not in an X11 session.

  + Frederic Crozat <fcrozat@mandriva.com>
    - Enable PolicyKit support

  + Thierry Vignaud <tv@mandriva.org>
    - fix summary-ended-with-dot
    - buildrequires X11-devel instead of XFree86-devel

* Mon Dec 03 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.8-5mdv2008.1
+ Revision: 114651
- Fix tunnel module to ignore device suspension.

* Thu Nov 29 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.8-4mdv2008.1
+ Revision: 113983
- Cherry pick r2078 from upstream to fix volume restore

* Wed Nov 28 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.8-3mdv2008.1
+ Revision: 113783
- Fix an issue with the tunnel module.

  + Thierry Vignaud <tv@mandriva.org>
    - use official esound capitalization in description

* Thu Nov 22 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.8-2mdv2008.1
+ Revision: 111248
- Fix loading samples (upstream r2074)

* Thu Nov 22 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.8-1mdv2008.1
+ Revision: 111113
- New version

* Fri Nov 02 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.7-5mdv2008.1
+ Revision: 105192
- Fix library packages.
- Add a RequiresL libltdl >= 1.5.24

* Thu Nov 01 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.7-4mdv2008.1
+ Revision: 104356
- Fix duplicated files list.

* Wed Oct 31 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.7-3mdv2008.1
+ Revision: 104088
- Fix groups that forgot to fix up.
- Add BuildRequires: lirc-devel
- Bump release.
- Major SPEC cleanup/restructure
- Split into subpackages to allow for minimal installations

* Tue Oct 30 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.7-1mdv2008.1
+ Revision: 103903
- New version

* Tue Oct 30 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.7-0.1989.1mdv2008.1
+ Revision: 103669
- Update to svn snapshot.
- New devel library policy

* Tue Aug 21 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.6-3mdv2008.0
+ Revision: 68411
- Fix a bug with avahi when names >64 chars long

* Mon Jul 30 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.6-2mdv2008.0
+ Revision: 56490
- Add patch for PA issue #49 (ignore underruns on tunnels)

* Sat Jun 02 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.6-1mdv2008.0
+ Revision: 34642
- New upstream release: 0.9.6

* Tue May 01 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.5-1.1437.1mdv2008.0
+ Revision: 19909
- Update to SVN r1437
- Includes stability fixes and suspend/resume support


* Mon Feb 05 2007 Colin Guthrie <cguthrie@mandriva.org> 0.9.5-1mdv2007.0
+ Revision: 116253
- Import pulseaudio

* Mon Aug 28 2006 Götz Waschk <waschk@mandriva.org> 0.9.5-1mdv2007.0
- fix buildrequires
- New release 0.9.5

* Wed Aug 02 2006 Frederic Crozat <fcrozat@mandriva.com> 0.9.4-2mdv2007.0
- Rebuild with latest dbus
- Change BR to use avahi instead of howl

* Wed Jul 26 2006 Götz Waschk <waschk@mandriva.org> 0.9.4-1mdv2007.0
- New release 0.9.4

* Sat Jul 22 2006 Götz Waschk <waschk@mandriva.org> 0.9.3-1mdv2007.0
- split out libpulsecore (changed major
- New release 0.9.3

* Tue Jul 11 2006 Götz Waschk <waschk@mandriva.org> 0.9.2-2mdv2007.0
- fix docs

* Tue Jul 11 2006 Götz Waschk <waschk@mandriva.org> 0.9.2-1mdv2007.0
- renamed from polypaudio

* Tue Jun 06 2006 Götz Waschk <waschk@mandriva.org> 0.9.1-1mdv2007.0
- update file list
- disable glib 1
- drop patch 
- New release 0.9.1

* Mon May 29 2006 Götz Waschk <waschk@mandriva.org> 0.9.0-1mdv2007.0
- new major
- New release 0.9.0

* Thu May 18 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.8.1-4mdk
- fix upgrade after file move in 0.8.1-3mdk

* Sat May 13 2006 Götz Waschk <waschk@mandriva.org> 0.8.1-3mdk
- move libpolypcore.so to lib package (bug #22431)

* Thu May 11 2006 Götz Waschk <waschk@mandriva.org> 0.8.1-2mdk
- add conflict to fix upgrade from stable

* Sat Apr 29 2006 Götz Waschk <waschk@mandriva.org> 0.8.1-1mdk
- New release 0.8.1

* Sat Apr 22 2006 Götz Waschk <waschk@mandriva.org> 0.8-1mdk
- update file list
- drop patch 0
- fix major
- fix buildrequires
- new version

* Wed Mar 08 2006 Götz Waschk <waschk@mandriva.org> 0.7-6mdk
- disable glib 1.2 main loop

* Sun Jan 01 2006 Mandriva Linux Team <http://www.mandrivaexpert.com/> 0.7-5mdk
- Rebuild

* Sat Apr 23 2005 Götz Waschk <waschk@mandriva.org> 0.7-4mdk
- fix build

* Thu Jan 06 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.7-3mdk
- add BuildRequires: libltdl-devel

* Wed Jan 05 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.7-2mdk
- use automake1.8

* Tue Jan 04 2005 Götz Waschk <waschk@linux-mandrake.com> 0.7-1mdk
- initial package

